# xmipy

![Continuous integration](https://github.com/Deltares/xmipy/workflows/Continuous%20integration/badge.svg)
[![codecov](https://codecov.io/gh/Deltares/xmipy/branch/develop/graph/badge.svg)](https://codecov.io/gh/Deltares/xmipy)


BMI python wrapper for MODFLOW 6 (and some more)
